@@ -29,3 +29,13 @@ table0 <- function(x) {
 
   purrr::set_names(res$n, res$tokens)
 }
+
+check_sparse_arg <- function(x) {
+  if (!is.null(x)) {
+    rlang::arg_match0(x, c("auto", "yes", "no"), arg_nm = "sparse")
+  }
+}
+
+sparse_is_yes <- function(x) {
+  !is.null(x) && x == "yes"
+}
