@@ -22,6 +22,7 @@
 #' @param sublinear_tf A logical, apply sublinear term-frequency scaling, i.e.,
 #'   replace the term frequency with 1 + log(TF). Defaults to FALSE.
 #' @template args-prefix
+#' @template args-sparse
 #' @template args-keep_original_cols
 #' @template args-skip
 #' @template args-id
@@ -53,7 +54,7 @@
 #'
 #' When you [`tidy()`][recipes::tidy.recipe()] this step, a tibble is returned with
 #' columns `terms`, `token`, `weight`, and `id`:
-#' 
+#'
 #' \describe{
 #'   \item{terms}{character, the selectors or variables selected}
 #'   \item{token}{character, name of token}
@@ -63,6 +64,8 @@
 #'
 #' @template details-prefix
 #'
+#' @template sparse-creation
+#'
 #' @template case-weights-not-supported
 #'
 #' @seealso [step_tokenize()] to turn characters into [`tokens`][tokenlist()]
@@ -89,20 +92,23 @@
 #'
 #' @export
 step_tfidf <-
-  function(recipe,
-           ...,
-           role = "predictor",
-           trained = FALSE,
-           columns = NULL,
-           vocabulary = NULL,
-           res = NULL,
-           smooth_idf = TRUE,
-           norm = "l1",
-           sublinear_tf = FALSE,
-           prefix = "tfidf",
-           keep_original_cols = FALSE,
-           skip = FALSE,
-           id = rand_id("tfidf")) {
+  function(
+    recipe,
+    ...,
+    role = "predictor",
+    trained = FALSE,
+    columns = NULL,
+    vocabulary = NULL,
+    res = NULL,
+    smooth_idf = TRUE,
+    norm = "l1",
+    sublinear_tf = FALSE,
+    prefix = "tfidf",
+    sparse = "auto",
+    keep_original_cols = FALSE,
+    skip = FALSE,
+    id = rand_id("tfidf")
+  ) {
     add_step(
       recipe,
       step_tfidf_new(
@@ -116,6 +122,7 @@ step_tfidf <-
         sublinear_tf = sublinear_tf,
         columns = columns,
         prefix = prefix,
+        sparse = sparse,
         keep_original_cols = keep_original_cols,
         skip = skip,
         id = id
@@ -124,8 +131,22 @@ step_tfidf <-
   }
 
 step_tfidf_new <-
-  function(terms, role, trained, columns, vocabulary, res, smooth_idf, norm,
-           sublinear_tf, prefix, keep_original_cols, skip, id) {
+  function(
+    terms,
+    role,
+    trained,
+    columns,
+    vocabulary,
+    res,
+    smooth_idf,
+    norm,
+    sublinear_tf,
+    prefix,
+    sparse,
+    keep_original_cols,
+    skip,
+    id
+  ) {
     step(
       subclass = "tfidf",
       terms = terms,
@@ -138,6 +159,7 @@ step_tfidf_new <-
       norm = norm,
       sublinear_tf = sublinear_tf,
       prefix = prefix,
+      sparse = sparse,
       keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
@@ -153,6 +175,7 @@ prep.step_tfidf <- function(x, training, info = NULL, ...) {
   rlang::arg_match0(x$norm, c("l1", "l2", "none"), arg_nm = "norm")
   check_bool(x$sublinear_tf, arg = "sublinear_tf")
   check_string(x$prefix, arg = "prefix")
+  check_sparse_arg(x$sparse)
 
   check_type(training[, col_names], types = "tokenlist")
 
@@ -176,6 +199,7 @@ prep.step_tfidf <- function(x, training, info = NULL, ...) {
     norm = x$norm,
     sublinear_tf = x$sublinear_tf,
     prefix = x$prefix,
+    sparse = x$sparse,
     keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
@@ -191,7 +215,7 @@ bake.step_tfidf <- function(object, new_data, ...) {
     # Backwards compatibility with 1.0.3 (#230)
     names(object$res) <- col_names
   }
-  
+
   for (col_name in col_names) {
     tfidf_text <- tfidf_function(
       new_data[[col_name]],
@@ -199,16 +223,22 @@ bake.step_tfidf <- function(object, new_data, ...) {
       paste0(object$prefix, "_", col_name),
       object$smooth_idf,
       object$norm,
-      object$sublinear_tf
+      object$sublinear_tf,
+      object$sparse
     )
 
-    tfidf_text <- recipes::check_name(tfidf_text, new_data, object, names(tfidf_text))
+    tfidf_text <- recipes::check_name(
+      tfidf_text,
+      new_data,
+      object,
+      names(tfidf_text)
+    )
 
     new_data <- vec_cbind(new_data, tfidf_text)
   }
-  
+
   new_data <- remove_original_cols(new_data, object, col_names)
-  
+
   new_data
 }
 
@@ -233,7 +263,8 @@ tidy.step_tfidf <- function(x, ...) {
       )
     } else {
       res <- purrr::map2_dfr(
-        x$columns, x$res,
+        x$columns,
+        x$res,
         ~ tibble(
           terms = .x,
           token = names(.y),
@@ -254,8 +285,15 @@ tidy.step_tfidf <- function(x, ...) {
 }
 
 # Implementation
-tfidf_function <- function(data, weights, labels, smooth_idf, norm,
-                           sublinear_tf) {
+tfidf_function <- function(
+  data,
+  weights,
+  labels,
+  smooth_idf,
+  norm,
+  sublinear_tf,
+  sparse
+) {
   # Backwards compatibility with 1592690d36581fc5f4952da3e9b02351b31f1a2e
   if (is.numeric(weights)) {
     dict <- names(weights)
@@ -264,13 +302,20 @@ tfidf_function <- function(data, weights, labels, smooth_idf, norm,
   }
   counts <- tokenlist_to_dtm(data, dict)
 
-  tfidf <- dtm_to_tfidf(counts, weights, smooth_idf, norm, sublinear_tf)
+  tfidf <- dtm_to_tfidf(counts, weights, smooth_idf, norm, sublinear_tf, sparse)
 
   colnames(tfidf) <- paste0(labels, "_", dict)
   as_tibble(tfidf)
 }
 
-dtm_to_tfidf <- function(dtm, idf_weights, smooth_idf, norm, sublinear_tf) {
+dtm_to_tfidf <- function(
+  dtm,
+  idf_weights,
+  smooth_idf,
+  norm,
+  sublinear_tf,
+  sparse
+) {
   dtm <- normalize(dtm, norm)
 
   if (sublinear_tf) {
@@ -288,7 +333,14 @@ dtm_to_tfidf <- function(dtm, idf_weights, smooth_idf, norm, sublinear_tf) {
   } else {
     out <- dtm %*% Matrix::Diagonal(x = idf_weights)
   }
-  as.matrix(out)
+
+  if (sparse_is_yes(sparse)) {
+    colnames(out) <- seq_len(ncol(out))
+    out <- sparsevctrs::coerce_to_sparse_tibble(out)
+  } else {
+    out <- as.matrix(out)
+  }
+  out
 }
 
 normalize <- function(dtm, norm = c("l1", "l2", "none")) {
@@ -296,7 +348,8 @@ normalize <- function(dtm, norm = c("l1", "l2", "none")) {
     return(dtm)
   }
 
-  norm_vec <- switch(norm,
+  norm_vec <- switch(
+    norm,
     l1 = 1 / Matrix::rowSums(dtm),
     l2 = 1 / sqrt(Matrix::rowSums(dtm^2))
   )
@@ -316,3 +369,22 @@ calc_idf <- function(dtm, smooth) {
 required_pkgs.step_tfidf <- function(x, ...) {
   c("textrecipes")
 }
+
+
+#' @export
+.recipes_estimate_sparsity.step_tfidf <- function(x, data, ...) {
+  get_levels <- function(col) {
+    n_chars <- nchar(col[seq(1, min(10, length(col)))])
+
+    floor(mean(n_chars))
+  }
+
+  n_levels <- lapply(data, get_levels)
+
+  lapply(n_levels, function(n_lvl) {
+    c(
+      n_cols = n_lvl,
+      sparsity = 1 - 1 / n_lvl
+    )
+  })
+}
