@@ -6,7 +6,7 @@ test_that("character input", {
   smith_tr <- Smithsonian[1:15, ]
   smith_te <- Smithsonian[16:20, ]
 
-  cleaned <- recipe(~., data = smith_tr) %>% 
+  cleaned <- recipe(~., data = smith_tr) %>%
     step_clean_levels(name, id = "")
 
   tidy_exp_un <- tibble(
@@ -38,10 +38,12 @@ test_that("character input", {
   expect_equal(tidy_exp_tr, tidy(cleaned, number = 1))
   expect_equal(
     cleaned_tr$name,
-    factor(c(
-      "anacostia_community_museum",
-      "arthur_m_sackler_gallery"
-    ))
+    factor(
+      c(
+        "anacostia_community_museum",
+        "arthur_m_sackler_gallery"
+      )
+    )
   )
   expect_equal(sum(is.na(cleaned_te$name)), 5)
 })
@@ -76,14 +78,14 @@ test_that("bake method errors when needed non-standard role columns are missing"
 
   data("Smithsonian", package = "modeldata")
   smith_tr <- Smithsonian[1:15, ]
-  
+
   rec <- recipe(~name, data = smith_tr) %>%
     step_clean_levels(name) %>%
     update_role(name, new_role = "potato") %>%
     update_role_requirements(role = "potato", bake = FALSE)
-  
+
   trained <- prep(rec, training = smith_tr, verbose = FALSE)
-  
+
   expect_snapshot(
     error = TRUE,
     bake(trained, new_data = smith_tr[, -1])
@@ -93,45 +95,45 @@ test_that("bake method errors when needed non-standard role columns are missing"
 test_that("empty printing", {
   rec <- recipe(mpg ~ ., mtcars)
   rec <- step_clean_levels(rec)
-  
+
   expect_snapshot(rec)
-  
+
   rec <- prep(rec, mtcars)
-  
+
   expect_snapshot(rec)
 })
 
 test_that("empty selection prep/bake is a no-op", {
   rec1 <- recipe(mpg ~ ., mtcars)
   rec2 <- step_clean_levels(rec1)
-  
+
   rec1 <- prep(rec1, mtcars)
   rec2 <- prep(rec2, mtcars)
-  
+
   baked1 <- bake(rec1, mtcars)
   baked2 <- bake(rec2, mtcars)
-  
+
   expect_identical(baked1, baked1)
 })
 
 test_that("empty selection tidy method works", {
   rec <- recipe(mpg ~ ., mtcars)
   rec <- step_clean_levels(rec)
-  
+
   expect <- tibble(terms = character(), id = character())
-  
+
   expect_identical(tidy(rec, number = 1), expect)
-  
+
   rec <- prep(rec, mtcars)
-  
+
   expect_identical(tidy(rec, number = 1), expect)
 })
 
 test_that("printing", {
   skip_if_not_installed("janitor")
-  rec <- recipe(~., data = iris) %>% 
+  rec <- recipe(~., data = iris) %>%
     step_clean_levels(Species)
-  
+
   expect_snapshot(print(rec))
   expect_snapshot(prep(rec))
 })
