@@ -1,9 +1,11 @@
-test_data <- tibble(text = c(
-  "I would not eat them here or there.",
-  "I would not eat them anywhere.",
-  "I would not eat green eggs and ham.",
-  "I do not like them, Sam-I-am."
-))
+test_data <- tibble(
+  text = c(
+    "I would not eat them here or there.",
+    "I would not eat them anywhere.",
+    "I would not eat green eggs and ham.",
+    "I do not like them, Sam-I-am."
+  )
+)
 
 rec <- recipe(~., data = test_data)
 
@@ -75,7 +77,7 @@ test_that("custom stopwords are supported", {
 
 test_that("bad args", {
   skip_if_not_installed("stopwords")
-  
+
   expect_snapshot(
     error = TRUE,
     recipe(~., data = mtcars) %>%
@@ -106,20 +108,20 @@ test_that("bad args", {
 
 test_that("bake method errors when needed non-standard role columns are missing", {
   skip_if_not_installed("stopwords")
-  
+
   tokenized_test_data <- recipe(~text, data = test_data) %>%
     step_tokenize(text) %>%
     prep() %>%
     bake(new_data = NULL)
-  
+
   rec <- recipe(tokenized_test_data) %>%
     update_role(text, new_role = "predictor") %>%
     step_stopwords(text) %>%
     update_role(text, new_role = "potato") %>%
     update_role_requirements(role = "potato", bake = FALSE)
-  
+
   trained <- prep(rec, training = tokenized_test_data, verbose = FALSE)
-  
+
   expect_snapshot(
     error = TRUE,
     bake(trained, new_data = tokenized_test_data[, -1])
@@ -128,29 +130,29 @@ test_that("bake method errors when needed non-standard role columns are missing"
 
 test_that("empty printing", {
   skip_if_not_installed("stopwords")
-  
+
   rec <- recipe(mpg ~ ., mtcars)
   rec <- step_stopwords(rec)
-  
+
   expect_snapshot(rec)
-  
+
   rec <- prep(rec, mtcars)
-  
+
   expect_snapshot(rec)
 })
 
 test_that("empty selection prep/bake is a no-op", {
   skip_if_not_installed("stopwords")
-  
+
   rec1 <- recipe(mpg ~ ., mtcars)
   rec2 <- step_stopwords(rec1)
-  
+
   rec1 <- prep(rec1, mtcars)
   rec2 <- prep(rec2, mtcars)
-  
+
   baked1 <- bake(rec1, mtcars)
   baked2 <- bake(rec2, mtcars)
-  
+
   expect_identical(baked1, baked1)
 })
 
@@ -159,18 +161,18 @@ test_that("empty selection tidy method works", {
 
   rec <- recipe(mpg ~ ., mtcars)
   rec <- step_stopwords(rec)
-  
+
   expect <- tibble(
     terms = character(),
     value = character(),
     keep = logical(),
     id = character()
   )
-  
+
   expect_identical(tidy(rec, number = 1), expect)
-  
+
   rec <- prep(rec, mtcars)
-  
+
   expect_identical(tidy(rec, number = 1), expect)
 })
 
@@ -179,7 +181,7 @@ test_that("printing", {
   rec <- rec %>%
     step_tokenize(text) %>%
     step_stopwords(text)
-  
+
   expect_snapshot(print(rec))
   expect_snapshot(prep(rec))
 })
