@@ -1,9 +1,11 @@
-test_data <- tibble(text = c(
-  "I would not eat them here or there.",
-  "I would not eat them anywhere.",
-  "I would not eat green eggs and ham.",
-  "I do not like them, Sam-I-am."
-))
+test_data <- tibble(
+  text = c(
+    "I would not eat them here or there.",
+    "I would not eat them anywhere.",
+    "I would not eat green eggs and ham.",
+    "I do not like them, Sam-I-am."
+  )
+)
 
 rec <- recipe(~., data = test_data)
 
@@ -65,11 +67,11 @@ test_that("step_tfidf works with vocabulary argument", {
 test_that("check_name() is used", {
   dat <- test_data
   dat$tfidf_text_i <- dat$text
-  
+
   rec <- recipe(~., data = dat) %>%
     step_tokenize(text) %>%
     step_tfidf(text)
-  
+
   expect_snapshot(
     error = TRUE,
     prep(rec, training = dat)
@@ -111,14 +113,20 @@ test_that("Backwards compatibility with 1592690d36581fc5f4952da3e9b02351b31f1a2e
   expect_snapshot(
     expect_equal(
       bake(rec, data) %>% slice(1),
-      tibble(tfidf_text_g = log(1 + 2 / 1) / 2, tfidf_text_i = log(1 + 2 / 2) / 2)
+      tibble(
+        tfidf_text_g = log(1 + 2 / 1) / 2,
+        tfidf_text_i = log(1 + 2 / 2) / 2
+      )
     )
   )
 
   expect_snapshot(
     expect_equal(
       bake(rec, data %>% slice(1)),
-      tibble(tfidf_text_g = log(1 + 2 / 2) / 2, tfidf_text_i = log(1 + 2 / 2) / 2)
+      tibble(
+        tfidf_text_g = log(1 + 2 / 2) / 2,
+        tfidf_text_i = log(1 + 2 / 2) / 2
+      )
     )
   )
 })
@@ -156,6 +164,101 @@ test_that("bad args", {
   )
 })
 
+test_that("sparse = 'yes' works", {
+  rec <- recipe(~., data = test_data)
+
+  dense <- rec %>%
+    step_tokenize(text) %>%
+    step_tfidf(text, norm = "l1", sparse = "no") %>%
+    prep() %>%
+    bake(NULL)
+  sparse <- rec %>%
+    step_tokenize(text) %>%
+    step_tfidf(text, norm = "l1", sparse = "yes") %>%
+    prep() %>%
+    bake(NULL)
+
+  expect_identical(dense, sparse)
+
+  expect_false(any(vapply(dense, sparsevctrs::is_sparse_double, logical(1))))
+  expect_true(all(vapply(sparse, sparsevctrs::is_sparse_double, logical(1))))
+
+  dense <- rec %>%
+    step_tokenize(text) %>%
+    step_tfidf(text, norm = "l2", sparse = "no") %>%
+    prep() %>%
+    bake(NULL)
+  sparse <- rec %>%
+    step_tokenize(text) %>%
+    step_tfidf(text, norm = "l2", sparse = "yes") %>%
+    prep() %>%
+    bake(NULL)
+
+  expect_identical(dense, sparse)
+
+  expect_false(any(vapply(dense, sparsevctrs::is_sparse_double, logical(1))))
+  expect_true(all(vapply(sparse, sparsevctrs::is_sparse_double, logical(1))))
+
+  dense <- rec %>%
+    step_tokenize(text) %>%
+    step_tfidf(text, norm = "none", sparse = "no") %>%
+    prep() %>%
+    bake(NULL)
+  sparse <- rec %>%
+    step_tokenize(text) %>%
+    step_tfidf(text, norm = "none", sparse = "yes") %>%
+    prep() %>%
+    bake(NULL)
+
+  expect_identical(dense, sparse)
+
+  expect_false(any(vapply(dense, sparsevctrs::is_sparse_double, logical(1))))
+  expect_true(all(vapply(sparse, sparsevctrs::is_sparse_double, logical(1))))
+
+  dense <- rec %>%
+    step_tokenize(text) %>%
+    step_tfidf(text, sublinear_tf = TRUE, sparse = "no") %>%
+    prep() %>%
+    bake(NULL)
+  sparse <- rec %>%
+    step_tokenize(text) %>%
+    step_tfidf(text, sublinear_tf = TRUE, sparse = "yes") %>%
+    prep() %>%
+    bake(NULL)
+
+  expect_identical(dense, sparse)
+
+  expect_false(any(vapply(dense, sparsevctrs::is_sparse_double, logical(1))))
+  expect_true(all(vapply(sparse, sparsevctrs::is_sparse_double, logical(1))))
+})
+
+test_that("sparse argument is backwards compatible", {
+  rec <- recipe(~., data = test_data) %>%
+    step_tokenize(text) %>%
+    step_tfidf(text, sparse = "no") %>%
+    prep()
+
+  exp <- bake(rec, test_data)
+
+  # Simulate old recipe
+  rec$steps[[1]]$sparse <- NULL
+
+  expect_identical(
+    bake(rec, test_data),
+    exp
+  )
+})
+
+test_that(".recipes_toggle_sparse_args works", {
+  rec <- recipe(~., data = test_data) %>%
+    step_tokenize(text) %>%
+    step_tfidf(text, sparse = "auto")
+
+  exp <- rec %>% prep() %>% bake(NULL) %>% sparsevctrs::sparsity()
+
+  expect_true(.recipes_estimate_sparsity(rec) >= exp)
+})
+
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
@@ -163,15 +266,15 @@ test_that("bake method errors when needed non-standard role columns are missing"
     step_tokenize(text) %>%
     prep() %>%
     bake(new_data = NULL)
-  
+
   rec <- recipe(tokenized_test_data) %>%
     update_role(text, new_role = "predictor") %>%
     step_tfidf(text) %>%
     update_role(text, new_role = "potato") %>%
     update_role_requirements(role = "potato", bake = FALSE)
-  
+
   trained <- prep(rec, training = tokenized_test_data, verbose = FALSE)
-  
+
   expect_snapshot(
     error = TRUE,
     bake(trained, new_data = tokenized_test_data[, -1])
@@ -181,73 +284,85 @@ test_that("bake method errors when needed non-standard role columns are missing"
 test_that("empty printing", {
   rec <- recipe(mpg ~ ., mtcars)
   rec <- step_tfidf(rec)
-  
+
   expect_snapshot(rec)
-  
+
   rec <- prep(rec, mtcars)
-  
+
   expect_snapshot(rec)
 })
 
 test_that("empty selection prep/bake is a no-op", {
   rec1 <- recipe(mpg ~ ., mtcars)
   rec2 <- step_tfidf(rec1)
-  
+
   rec1 <- prep(rec1, mtcars)
   rec2 <- prep(rec2, mtcars)
-  
+
   baked1 <- bake(rec1, mtcars)
   baked2 <- bake(rec2, mtcars)
-  
+
   expect_identical(baked1, baked1)
 })
 
 test_that("empty selection tidy method works", {
   rec <- recipe(mpg ~ ., mtcars)
   rec <- step_tfidf(rec)
-  
+
   expect <- tibble(
     terms = character(),
     token = character(),
     weight = double(),
     id = character()
   )
-  
+
   expect_identical(tidy(rec, number = 1), expect)
-  
+
   rec <- prep(rec, mtcars)
-  
+
   expect_identical(tidy(rec, number = 1), expect)
 })
 
 test_that("keep_original_cols works", {
   new_names <- c(
-    "tfidf_text_am", "tfidf_text_and", "tfidf_text_anywhere", "tfidf_text_do", 
-    "tfidf_text_eat", "tfidf_text_eggs", "tfidf_text_green", "tfidf_text_ham", 
-    "tfidf_text_here", "tfidf_text_i", "tfidf_text_like", "tfidf_text_not", 
-    "tfidf_text_or", "tfidf_text_sam", "tfidf_text_them", "tfidf_text_there", 
+    "tfidf_text_am",
+    "tfidf_text_and",
+    "tfidf_text_anywhere",
+    "tfidf_text_do",
+    "tfidf_text_eat",
+    "tfidf_text_eggs",
+    "tfidf_text_green",
+    "tfidf_text_ham",
+    "tfidf_text_here",
+    "tfidf_text_i",
+    "tfidf_text_like",
+    "tfidf_text_not",
+    "tfidf_text_or",
+    "tfidf_text_sam",
+    "tfidf_text_them",
+    "tfidf_text_there",
     "tfidf_text_would"
   )
-  
+
   rec <- recipe(~text, data = test_data) %>%
     step_tokenize(text) %>%
     step_tfidf(text, keep_original_cols = FALSE)
-  
+
   rec <- prep(rec)
   res <- bake(rec, new_data = NULL)
-  
+
   expect_equal(
     colnames(res),
     new_names
   )
-  
+
   rec <- recipe(~text, data = test_data) %>%
     step_tokenize(text) %>%
     step_tfidf(text, keep_original_cols = TRUE)
-  
+
   rec <- prep(rec)
   res <- bake(rec, new_data = NULL)
-  
+
   expect_equal(
     colnames(res),
     c("text", new_names)
@@ -258,13 +373,13 @@ test_that("keep_original_cols - can prep recipes with it missing", {
   rec <- recipe(~text, data = test_data) %>%
     step_tokenize(text) %>%
     step_tfidf(text)
-  
+
   rec$steps[[2]]$keep_original_cols <- NULL
-  
+
   expect_snapshot(
     rec <- prep(rec)
   )
-  
+
   expect_no_error(
     bake(rec, new_data = test_data)
   )
@@ -274,7 +389,7 @@ test_that("printing", {
   rec <- rec %>%
     step_tokenize(text) %>%
     step_tfidf(text)
-  
+
   expect_snapshot(print(rec))
   expect_snapshot(prep(rec))
 })
