@@ -1,9 +1,11 @@
-test_data <- tibble(text = c(
-  "I would not eat them here or there.",
-  "I would not eat them anywhere.",
-  "I would not eat green eggs and ham.",
-  "I do not like them, Sam-I-am."
-))
+test_data <- tibble(
+  text = c(
+    "I would not eat them here or there.",
+    "I would not eat them anywhere.",
+    "I would not eat green eggs and ham.",
+    "I do not like them, Sam-I-am."
+  )
+)
 
 rec <- recipe(~., data = test_data)
 
@@ -117,7 +119,7 @@ test_that("tokenfilter works with filter_fun", {
 test_that("tunable", {
   rec <-
     recipe(~., data = mtcars) %>%
-    step_tokenfilter(all_predictors())
+      step_tokenfilter(all_predictors())
   rec_param <- tunable.step_tokenfilter(rec$steps[[1]])
   expect_equal(rec_param$name, c("max_times", "min_times", "max_tokens"))
   expect_true(all(rec_param$source == "recipe"))
@@ -181,15 +183,15 @@ test_that("bake method errors when needed non-standard role columns are missing"
     step_tokenize(text) %>%
     prep() %>%
     bake(new_data = NULL)
-  
+
   rec <- recipe(tokenized_test_data) %>%
     update_role(text, new_role = "predictor") %>%
     step_tokenfilter(text, max_tokens = 10) %>%
     update_role(text, new_role = "potato") %>%
     update_role_requirements(role = "potato", bake = FALSE)
-  
+
   trained <- prep(rec, training = tokenized_test_data, verbose = FALSE)
-  
+
   expect_snapshot(
     error = TRUE,
     bake(trained, new_data = tokenized_test_data[, -1])
@@ -199,37 +201,37 @@ test_that("bake method errors when needed non-standard role columns are missing"
 test_that("empty printing", {
   rec <- recipe(mpg ~ ., mtcars)
   rec <- step_tokenfilter(rec)
-  
+
   expect_snapshot(rec)
-  
+
   rec <- prep(rec, mtcars)
-  
+
   expect_snapshot(rec)
 })
 
 test_that("empty selection prep/bake is a no-op", {
   rec1 <- recipe(mpg ~ ., mtcars)
   rec2 <- step_tokenfilter(rec1)
-  
+
   rec1 <- prep(rec1, mtcars)
   rec2 <- prep(rec2, mtcars)
-  
+
   baked1 <- bake(rec1, mtcars)
   baked2 <- bake(rec2, mtcars)
-  
+
   expect_identical(baked1, baked1)
 })
 
 test_that("empty selection tidy method works", {
   rec <- recipe(mpg ~ ., mtcars)
   rec <- step_tokenfilter(rec)
-  
+
   expect <- tibble(terms = character(), value = integer(), id = character())
-  
+
   expect_identical(tidy(rec, number = 1), expect)
-  
+
   rec <- prep(rec, mtcars)
-  
+
   expect_identical(tidy(rec, number = 1), expect)
 })
 
@@ -237,7 +239,7 @@ test_that("printing", {
   rec <- rec %>%
     step_tokenize(text) %>%
     step_tokenfilter(text)
-  
+
   expect_snapshot(print(rec))
   expect_snapshot(prep(rec))
 })
@@ -251,9 +253,9 @@ test_that("tunable is setup to works with extract_parameter_set_dials", {
       min_times = hardhat::tune(),
       max_tokens = hardhat::tune()
     )
-  
+
   params <- extract_parameter_set_dials(rec)
-  
+
   expect_s3_class(params, "parameters")
   expect_identical(nrow(params), 3L)
 })
