@@ -1,9 +1,11 @@
-test_data <- tibble(text = c(
-  "I would not eat them here or there.",
-  "I would not eat them anywhere.",
-  "I would not eat green eggs and ham.",
-  "I do not like them, Sam-I-am."
-))
+test_data <- tibble(
+  text = c(
+    "I would not eat them here or there.",
+    "I would not eat them anywhere.",
+    "I would not eat green eggs and ham.",
+    "I do not like them, Sam-I-am."
+  )
+)
 
 rec <- recipe(~., data = test_data)
 
@@ -54,7 +56,10 @@ test_that("tokenization works with other built-in tokenizers", {
 
   expect_equal(
     tokenizers::tokenize_characters(test_data$text[1]),
-    bake(rec, new_data = NULL) %>% slice(1) %>% pull(text) %>% vctrs::field("tokens")
+    bake(rec, new_data = NULL) %>%
+      slice(1) %>%
+      pull(text) %>%
+      vctrs::field("tokens")
   )
 })
 
@@ -127,7 +132,7 @@ test_that("tokenization doesn't includes lemma attribute when unavaliable", {
 test_that("tunable", {
   rec <-
     recipe(~., data = mtcars) %>%
-    step_tokenize(all_predictors())
+      step_tokenize(all_predictors())
   rec_param <- tunable.step_tokenize(rec$steps[[1]])
   expect_equal(rec_param$name, c("token"))
   expect_true(all(rec_param$source == "recipe"))
@@ -167,9 +172,9 @@ test_that("bake method errors when needed non-standard role columns are missing"
     step_tokenize(text) %>%
     update_role(text, new_role = "potato") %>%
     update_role_requirements(role = "potato", bake = FALSE)
-  
+
   trained <- prep(rec, training = test_data, verbose = FALSE)
-  
+
   expect_snapshot(
     error = TRUE,
     bake(trained, new_data = test_data[, -1])
@@ -179,44 +184,44 @@ test_that("bake method errors when needed non-standard role columns are missing"
 test_that("empty printing", {
   rec <- recipe(mpg ~ ., mtcars)
   rec <- step_tokenize(rec)
-  
+
   expect_snapshot(rec)
-  
+
   rec <- prep(rec, mtcars)
-  
+
   expect_snapshot(rec)
 })
 
 test_that("empty selection prep/bake is a no-op", {
   rec1 <- recipe(mpg ~ ., mtcars)
   rec2 <- step_tokenize(rec1)
-  
+
   rec1 <- prep(rec1, mtcars)
   rec2 <- prep(rec2, mtcars)
-  
+
   baked1 <- bake(rec1, mtcars)
   baked2 <- bake(rec2, mtcars)
-  
+
   expect_identical(baked1, baked1)
 })
 
 test_that("empty selection tidy method works", {
   rec <- recipe(mpg ~ ., mtcars)
   rec <- step_tokenize(rec)
-  
+
   expect <- tibble(terms = character(), value = character(), id = character())
-  
+
   expect_identical(tidy(rec, number = 1), expect)
-  
+
   rec <- prep(rec, mtcars)
-  
+
   expect_identical(tidy(rec, number = 1), expect)
 })
 
 test_that("printing", {
   rec <- rec %>%
     step_tokenize(text)
-  
+
   expect_snapshot(print(rec))
   expect_snapshot(prep(rec))
 })
@@ -228,9 +233,9 @@ test_that("tunable is setup to works with extract_parameter_set_dials", {
       all_predictors(),
       token = hardhat::tune()
     )
-  
+
   params <- extract_parameter_set_dials(rec)
-  
+
   expect_s3_class(params, "parameters")
   expect_identical(nrow(params), 1L)
 })
